@@ -224,21 +224,25 @@ class SambaWalker(OsWalker):
         
     def putFileToHost(self, file):
         self.doCommand(
-            'mput ' + file,
+            'mput ' + file
+        )
+        return self
+        
+    def getFileFromHost(self, file):
+        self.doCommand(
+            'mget ' + file
+        )
+        return self
+        
+    def doCommand(self, command):
+        super(SambaWalker, self).doCommand(
+            command,
             maybeExpecter = {
                 '?:':'y\n',
             }, 
             needExpecter = self.needExpecterMain
         )
-        
-    def getFileFromHost(self, file):
-        self.doCommand(
-            'mget ' + file,
-            maybeExpecter = {
-                '?:':'y\n',
-            },
-            needExpecter = self.needExpecterMain
-        )
+        return self
         
 class SuWalker(OsWalker):
     def __init__(self, user, password, baseWalker=False):
